FaceidPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FaceidPlatform
Implementers

Constructors

FaceidPlatform()
Constructs a FaceidPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate() → Future<bool>
Authenticates the user using Face ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FaceidPlatform
The default instance of FaceidPlatform to use.
getter/setter pair